@@ -12,14 +12,24 @@ typedef enum FFGPUType
     FF_GPU_TYPE_DISCRETE,
 } FFGPUType;
 
+typedef enum FFGPUDetectionMethod
+{
+    FF_GPU_DETECTION_METHOD_AUTO,
+    FF_GPU_DETECTION_METHOD_PCI,
+    FF_GPU_DETECTION_METHOD_VULKAN,
+    FF_GPU_DETECTION_METHOD_OPENGL,
+} FFGPUDetectionMethod;
+
 typedef struct FFGPUOptions
 {
     FFModuleBaseInfo moduleInfo;
     FFModuleArgs moduleArgs;
 
     FFGPUType hideType;
+    FFGPUDetectionMethod detectionMethod;
     bool temp;
     bool driverSpecific;
-    bool forceVulkan;
-    FFPercentConfig percent;
+    bool forceMethod;
+    FFColorRangeConfig tempConfig;
+    FFColorRangeConfig percent;
 } FFGPUOptions;
